@@ -59,4 +59,4 @@ class Alert(object):
 
     @property
     def utc_time(self):
-        return to_unix_time(self._data.get(utc_time))
+        return to_unix_time(self._data.get("utc_time"))
